// ---------------------------------------------------------------------------
// ammoHUD.cs -- Version 1.4 -- December 31, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Display your current weapon's ammo (very unobtrusively) in a small HUD
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\ammoHUD.cs", "1.4", "Lorne Laliberte", "Dec 31, 2000");

include("writer\\bitmap_strings.cs");
include("writer\\event.cs");
include("writer\\inventory.cs");
include("writer\\save.cs");
include("writer\\weapon_switch.cs");
include("writer\\whud.cs");
include("writer\\you_died.cs");
include("writer\\you_respawned.cs");
include("writer\\you_spawned.cs");

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_ammoHUD.cs file

    // Screen coordinates for ammoHUD
    $ammoHUD::X = "l:xhair-14";
    $ammoHUD::Y = "50%";

    // Screen coordinates for ammoHUD when the xhair.cs rangefinder is active
    $ammoHUD::rangeX = "l:xhair-14";
    $ammoHUD::rangeY = "50%";

    // Default text colour, from 0 to 2 (ignored if bitmaps are used)
    $ammoHUD::textColour = "1";

    // Make the ammoHUD background transparent
    $ammoHUD::Transparent = "true";

    // Use the tiny red or green text bitmaps I've designed instead of the
    // normal Tribes font
    $ammoHUD::useBitmaps = "true";

    // Default bitmap colour -- can be either "green" or "red"
    $ammoHUD::normalBitmapColour = "green";

    // Use outline bitmaps (black background) -- use "2" if you want to force
    // the outline for red bitmaps, otherwise only green bitmaps will have the
    // black background (I find it easier to read that way)
    $ammoHUD::useOutlineBitmaps = "true";

    // Bitmap colour for low-ammo situations -- can be either "green" or "red"
    $ammoHUD::lowAmmoBitmapColour = "red";

    // Low-ammo levels at which bitmap colour will change
    // use: ammoHUD::lowAmmo("<weapon name>", <rounds>);
    ammoHUD::lowAmmo("Chaingun", 20);
    ammoHUD::lowAmmo("Disc Launcher", 4);
    ammoHUD::lowAmmo("Grenade Launcher", 3);
    ammoHUD::lowAmmo("Mortar", 3);
    ammoHUD::lowAmmo("Plasma Gun", 6);

    // How much extra padding you would like between each bitmap character
    $ammoHUD::letterPadding = "0";

    // Right-justify the ammoHUD contents
    $ammoHUD::rightJustify = "true";

    // Prefix (like "Ammo: " or something) -- ignored if bitmaps are used
    $ammoHUD::prefix = "";

    // Width in pixels -- make sure this is wide enough for the contents
    $ammoHUD::width = "20";

    // Cycle through available colours -- does nothing if bitmaps are used
    //bind(keyboard0, make, alt, "whatever", TO, "ammoHUD::nextColour();");

// ---------------------------------------------------------------------------

WriterPrefs::load("ammoHUD");

$ammoHUD::ColourText[0] = "<f0>";
$ammoHUD::ColourText[1] = "<f1>";
$ammoHUD::ColourText[2] = "<f2>";

function ammoHUD::nextColour()
{
    if($ammoHUD::useBitmaps)
    {
        if(!String::ICompare($ammoHUD::bitmapColour, green))
            $ammoHUD::bitmapColour = red;
        else
            $ammoHUD::bitmapColour = green;
    }
    else
    {
        $ammoHUD::textColour++;
        if($ammoHUD::textColour > 2)
            $ammoHUD::textColour = 0;
    }
    wHUD::update(ammoHUD, ammoHUD::text());
}


function ammoHUD::height()
{
    if($ammoHUD::transparent && $ammoHUD::useBitmaps)
        return $ammoHUD::height = 9;
    else
        return $ammoHUD::height = 18;
}

function ammoHUD::text()
{
    if($ammoHUD::useBitmaps)
        return $ammoHUD::currentText = getBitmapStr($ammoHUD::ammo_count, $ammoHUD::bitmapColour, $ammoHUD::rightJustify, 0, 0, $ammoHUD::letterPadding, "", false, $ammoHUD::useOutlineBitmaps);
    else
    {
        $ammoHUD::currentText = wif($ammoHUD::rightJustify, "<jr>", "") @ $ammoHUD::ColourText[$ammoHUD::textColour] @ $ammoHUD::prefix @ $ammoHUD::ammo_count;
        if((%width = getStrPixels($ammoHUD::currentText)) > $ammoHUD::width)
            $ammoHUD::width = %width;
        return $ammoHUD::currentText;
    }
}


function ammoHUD::onYouSpawned()
{
    // Build ammoHUD on first weapon switch, after playGui exists
    if(!wHUD::exists(ammoHUD))
    {
        wHUD::makeMoveable(1, 1, 0, ammoHUD, $ammoHUD::x, $ammoHUD::y, $ammoHUD::width + wif(!$ammoHUD::transparent && !$ammoHUD::useBitmaps, 6, 0), ammoHUD::height(), $ammoHUD::transparent, true, ammoHUD::text(), wif(!$ammoHUD::transparent && !$ammoHUD::useBitmaps, 3, ""));
    }
    else
    {
        wHUD::show(ammoHUD);
    }
    return;
}

function ammoHUD::relocate()
{
    wHUD::makeMoveable(1, 1, 0, ammoHUD, $ammoHUD::x, $ammoHUD::y, $ammoHUD::width + wif(!$ammoHUD::transparent && !$ammoHUD::useBitmaps, 6, 0), ammoHUD::height(), $ammoHUD::transparent, true, $ammoHUD::currentText, wif(!$ammoHUD::transparent && !$ammoHUD::useBitmaps, 3, ""));
    return;
}


function onHudMove_ammoHUD(%x, %y, %width, %height)
{
    $ammoHUD::x = %x;
    $ammoHUD::y = %y;
    $ammoHUD::width = %width;
    wHUD::makeMoveable(1, 1, 0, ammoHUD, $ammoHUD::x, $ammoHUD::y, $ammoHUD::width + wif(!$ammoHUD::transparent && !$ammoHUD::useBitmaps, 6, 0), ammoHUD::height(), $ammoHUD::transparent, true, $ammoHUD::currentText, wif(!$ammoHUD::transparent && !$ammoHUD::useBitmaps, 3, ""));

    if(String::findSubStr($ammoHUD::x @ $ammoHUD::y @ $ammoHUD::width, "xhair") != -1)
        Event::Attach(eventXhairDimensionsChanged, "ammoHUD::onXhairDimensionsChanged();");

    return;
}

    

function ammoHUD::onAmmoChange(%ammo, %weapon)
{
    if(%ammo)
    {
        $ammoHUD::ammo_count = %ammo;

        if($ammoHUD::useBitmaps)
        {
            if(%ammo > $ammoHUD::lowAmmo[$Inv::Name[%weapon]])
                $ammoHUD::bitmapColour = $ammoHUD::normalBitmapColour;
            else
                $ammoHUD::bitmapColour = $ammoHUD::lowAmmoBitmapColour;
        }        
    }
    else
        $ammoHUD::ammo_count = "";


    
    wHUD::update(ammoHUD, ammoHUD::text());
    return;
}


// Update ammoHUD position if xhair became wider or taller, just in case a position relative to xhair was used
function ammoHUD::onXhairDimensionsChanged()
{
    wHUD::makeMoveable(1, 1, 0, ammoHUD, $ammoHUD::x, $ammoHUD::y, $ammoHUD::width + wif(!$ammoHUD::transparent && !$ammoHUD::useBitmaps, 6, 0), ammoHUD::height(), $ammoHUD::transparent, true, $ammoHUD::currentText, wif(!$ammoHUD::transparent && !$ammoHUD::useBitmaps, 3, ""));
}


function ammoHUD::onRangeFinderOn()
{
    if(($ammoHUD::x == $ammoHUD::rangeX) && ($ammoHUD::y == $ammoHUD::rangeY))
        return;

    wHUD::makeMoveable(1, 1, 0, ammoHUD, $ammoHUD::x, $ammoHUD::y, $ammoHUD::width + wif(!$ammoHUD::transparent && !$ammoHUD::useBitmaps, 6, 0), ammoHUD::height(), $ammoHUD::transparent, true, $ammoHUD::currentText, wif(!$ammoHUD::transparent && !$ammoHUD::useBitmaps, 3, ""));
}


function ammoHUD::onRangeFinderOff()
{
    if(($ammoHUD::x == $ammoHUD::rangeX) && ($ammoHUD::y == $ammoHUD::rangeY))
        return;

    wHUD::makeMoveable(1, 1, 0, ammoHUD, $ammoHUD::x, $ammoHUD::y, $ammoHUD::width + wif(!$ammoHUD::transparent && !$ammoHUD::useBitmaps, 6, 0), ammoHUD::height(), $ammoHUD::transparent, true, $ammoHUD::currentText, wif(!$ammoHUD::transparent && !$ammoHUD::useBitmaps, 3, ""));
}


function ammoHUD::save()
{
    AddExportText("    // Screen coordinates for ammoHUD");
    ExportSetting("    $ammoHUD::X", "l:xhair-14", "", "14 pixels left of the xhair reticle");
    ExportSetting("    $ammoHUD::Y", "50%");
    AddExportText("");
    AddExportText("    // Screen coordinates for ammoHUD when the xhair.cs rangefinder is active");
    ExportSetting("    $ammoHUD::rangeX", "l:xhair-14", "", "14 pixels left of the xhair reticle");
    ExportSetting("    $ammoHUD::rangeY", "50%");
    AddExportText("");
    AddExportText("    // Default text colour, from 0 to 2 (ignored if bitmaps are used)");
    ExportSetting("    $ammoHUD::textColour", 1);
    AddExportText("");
    AddExportText("    // Make the ammoHUD background transparent");
    ExportSetting("    $ammoHUD::Transparent", true);
    AddExportText("");
    AddExportText("    // Use the tiny red or green text bitmaps I've designed instead of the");
    AddExportText("    // normal Tribes font");
    ExportSetting("    $ammoHUD::useBitmaps", true);
    AddExportText("");
    AddExportText("    // Use outline bitmaps (black background) -- use \"2\" if you want to force");
    AddExportText("    // the outline for red bitmaps, otherwise only green bitmaps will have the");
    AddExportText("    // black background (I find it easier to read that way)");
    ExportSetting("    $ammoHUD::useOutlineBitmaps", true);
    AddExportText("");
    AddExportText("    // Default bitmap colour -- can be either \"green\" or \"red\"");
    ExportSetting("    $ammoHUD::normalBitmapColour", "green");
    AddExportText("");
    AddExportText("    // Bitmap colour for low-ammo situations -- can be either \"green\" or \"red\"");
    ExportSetting("    $ammoHUD::lowAmmoBitmapColour", "red");
    AddExportText("");
    AddExportText("    // Low-ammo levels at which bitmap colour will change");
    AddExportText("    // use: ammoHUD::lowAmmo(\"<weapon name>\", <rounds>);");

    if(!ExportIndexed("    ammoHUD::lowAmmo(%1, %2);", "$ammoHUD::lowAmmo[%1]", "$ammoHUD::lowAmmo::index[%1]", 1, $ammoHUD::lowAmmo::count))
    {
        AddExportText("    ammoHUD::lowAmmo(\"Chaingun\", 20);");
        AddExportText("    ammoHUD::lowAmmo(\"Disc Launcher\", 4);");
        AddExportText("    ammoHUD::lowAmmo(\"Grenade Launcher\", 3);");
        AddExportText("    ammoHUD::lowAmmo(\"Mortar\", 3);");
        AddExportText("    ammoHUD::lowAmmo(\"Plasma Gun\", 6);");
    }

    AddExportText("");
    AddExportText("    // How much extra padding you would like between each bitmap character");
    ExportSetting("    $ammoHUD::letterPadding", 0);
    AddExportText("");
    AddExportText("    // Right-justify the ammoHUD contents");
    ExportSetting("    $ammoHUD::rightJustify", true);
    AddExportText("");
    AddExportText("    // Prefix (like \"Zoom: \" or something) -- ignored if bitmaps are used");
    ExportSetting("    $ammoHUD::prefix", "");
    AddExportText("");
    AddExportText("    // Width in pixels -- make sure this is wide enough for the contents");
    ExportSetting("    $ammoHUD::width", 20);
    AddExportText("");
    AddExportText("    // Cycle through available colours -- does nothing if bitmaps are used");

    ExportBind("ammoHUD::nextColour();", "//bind(keyboard0, make, alt, \"whatever\", TO, \"ammoHUD::nextColour();\");");
}

WriterPrefs::save("ammoHUD");

function ammoHUD::init()
{
    needs("writer\\ammoHUD.cs", "writer\\bitmap_strings.cs 1.2",
                                "writer\\event.cs 2.7",
                                "writer\\inventory.cs 3.3",
                                "writer\\save.cs 2.3",
                                "writer\\whud.cs 1.2",
                                "writer\\weapon_switch.cs 2.5",
                                "writer\\you_died.cs 1.6",
                                "writer\\you_respawned.cs 1.2",
                                "writer\\you_spawned.cs 1.1");

    Event::Attach(eventAmmoChange, ammoHUD::onAmmoChange);
    Event::Attach(wHudSave_ammoHUD, "ammoHUD::save();");

    Event::Attach(eventRangeFinderOn, "ammoHUD::onRangeFinderOn();");
    Event::Attach(eventRangeFinderOn, "ammoHUD::onRangeFinderOff();");

    if(String::findSubStr($ammoHUD::x @ $ammoHUD::y @ $ammoHUD::width, "xhair") != -1)
        Event::Attach(eventXhairDimensionsChanged, "ammoHUD::onXhairDimensionsChanged();");

    Event::Attach(eventYouSpawned, "ammoHUD::onYouSpawned();");
    Event::Attach(eventYouRespawned, "wHUD::show(ammoHUD);");
    Event::Attach(eventChangeMission, "wHUD::hide(ammoHUD);");
    Event::Attach(eventScreenModeChanged, "ammoHUD::relocate();");
    Event::Attach(eventScreenSizeChanged, "ammoHUD::relocate();");
    Event::Attach(wHudMoved, "ammoHUD::relocate();");
    Event::Attach(wHudMove_ammoHUD, onHudMove_ammoHUD);
    Event::Attach(wHudSave_ammoHUD, "WriterPrefs::save(\"ammoHUD\");");
}
Event::Attach(writerInit, "ammoHUD::init();");

if(!$UsingWriterLoader) ammoHUD::init();
